struct TrackedBindings {
bindings: Vec<TrackedBinding>,
}Fields
bindings: Vec<TrackedBinding>Implementations
Sourceimpl TrackedBindings
impl TrackedBindings
fn new() -> Self
Sourcefn try_merge(
&mut self,
c: &mut Compiler<'_, '_>,
name: &Attr,
entry: AttributeEntry,
) -> Result<(), AttributeEntry>
fn try_merge( &mut self, c: &mut Compiler<'_, '_>, name: &Attr, entry: AttributeEntry, ) -> Result<(), AttributeEntry>
Attempt to merge an entry into an existing matching binding, assuming that the provided binding is mergable (i.e. either a nested key or an attribute set literal).
Returns Ok if the binding was merged, Err if it needs to be compiled
separately as a new binding.