ScopeGuard

Struct ScopeGuard 

pub(crate) struct ScopeGuard {
    depth: usize,
    name: &'static str,
}
Guard that helps uphold the scope depth correctness invariant.

Scopes should be closed and they should be closed in the right order. If that isn’t the case the compiler has somehow lost track of scopes and the resulting program will not be correct.

Fields

depth: usize
Available on debug-assertions enabled only.
name: &'static str
Available on debug-assertions enabled only.

Implementations

Source

impl ScopeGuard

fn new(depth: usize, name: &'static str) -> Self

fn close(self, depth: usize)