pub struct Error {
pub kind: ErrorKind,
pub span: Span,
pub contexts: Vec<String>,
pub source: SourceCode,
}Fields
kind: ErrorKindspan: Spancontexts: Vec<String>source: SourceCodeImplementations
Sourceimpl Error
impl Error
pub fn fancy_format_str(&self) -> String
Sourcepub fn fancy_format_stderr(&self)
pub fn fancy_format_stderr(&self)
Render a fancy, human-readable output of this error and print it to stderr.
Sourcepub fn fancy_format_write<E: Write + Send>(&self, stderr: &mut E)
pub fn fancy_format_write<E: Write + Send>(&self, stderr: &mut E)
Render a fancy, human-readable output of this error and print it to a std::io::Write.
Sourcefn span_label(&self) -> Option<String>
fn span_label(&self) -> Option<String>
Create the optional span label displayed as an annotation on the underlined span of the error.
Sourcefn code(&self) -> &'static str
fn code(&self) -> &'static str
Return the unique error code for this variant which can be used to refer users to documentation.
fn spans(&self) -> Vec<SpanLabel>
Sourcefn diagnostic(&self) -> Diagnostic
fn diagnostic(&self) -> Diagnostic
Create the primary diagnostic for a given error.
Sourcefn diagnostics(&self) -> Vec<Diagnostic>
fn diagnostics(&self) -> Vec<Diagnostic>
Return the primary diagnostic and all further associated diagnostics (if any) of an error.