pub struct NoOpObserver {}Trait Implementations
Sourceimpl CompilerObserver for NoOpObserver
impl CompilerObserver for NoOpObserver
Sourcefn observe_compiled_toplevel(&mut self, _: &Rc<Lambda>)
fn observe_compiled_toplevel(&mut self, _: &Rc<Lambda>)
Called when the compiler finishes compilation of the top-level
of an expression (usually the root Nix expression of a file).
Sourcefn observe_compiled_lambda(&mut self, _: &Rc<Lambda>)
fn observe_compiled_lambda(&mut self, _: &Rc<Lambda>)
Called when the compiler finishes compilation of a
user-defined function. Read more
Sourcefn observe_compiled_thunk(&mut self, _: &Rc<Lambda>)
fn observe_compiled_thunk(&mut self, _: &Rc<Lambda>)
Called when the compiler finishes compilation of a thunk.
Sourceimpl Default for NoOpObserver
impl Default for NoOpObserver
Sourcefn default() -> NoOpObserver
fn default() -> NoOpObserver
Returns the “default value” for a type. Read more
Sourceimpl RuntimeObserver for NoOpObserver
impl RuntimeObserver for NoOpObserver
Sourcefn observe_enter_bytecode_frame(
&mut self,
_arg_count: usize,
_: &Rc<Lambda>,
_call_depth: usize,
)
fn observe_enter_bytecode_frame( &mut self, _arg_count: usize, _: &Rc<Lambda>, _call_depth: usize, )
Called when the runtime enters a new bytecode frame.
Sourcefn observe_exit_bytecode_frame(&mut self, _frame_at: usize, _stack: &[Value])
fn observe_exit_bytecode_frame(&mut self, _frame_at: usize, _stack: &[Value])
Called when the runtime exits a bytecode frame.
Sourcefn observe_suspend_bytecode_frame(&mut self, _frame_at: usize, _stack: &[Value])
fn observe_suspend_bytecode_frame(&mut self, _frame_at: usize, _stack: &[Value])
Called when the runtime suspends a bytecode frame.
Sourcefn observe_enter_generator(
&mut self,
_frame_at: usize,
_name: &str,
_stack: &[Value],
)
fn observe_enter_generator( &mut self, _frame_at: usize, _name: &str, _stack: &[Value], )
Called when the runtime enters a generator frame.
Sourcefn observe_exit_generator(
&mut self,
_frame_at: usize,
_name: &str,
_stack: &[Value],
)
fn observe_exit_generator( &mut self, _frame_at: usize, _name: &str, _stack: &[Value], )
Called when the runtime exits a generator frame.
Sourcefn observe_suspend_generator(
&mut self,
_frame_at: usize,
_name: &str,
_stack: &[Value],
)
fn observe_suspend_generator( &mut self, _frame_at: usize, _name: &str, _stack: &[Value], )
Called when the runtime suspends a generator frame.
Sourcefn observe_generator_request(&mut self, _name: &str, _msg: &VMRequest)
fn observe_generator_request(&mut self, _name: &str, _msg: &VMRequest)
Called when a generator requests an action from the VM.
Sourcefn observe_tail_call(&mut self, _frame_at: usize, _: &Rc<Lambda>)
fn observe_tail_call(&mut self, _frame_at: usize, _: &Rc<Lambda>)
Called when the runtime replaces the current bytecode frame for a
tail call.
Sourcefn observe_enter_builtin(&mut self, _name: &'static str)
fn observe_enter_builtin(&mut self, _name: &'static str)
Called when the runtime enters a builtin.
Sourcefn observe_exit_builtin(&mut self, _name: &'static str, _stack: &[Value])
fn observe_exit_builtin(&mut self, _name: &'static str, _stack: &[Value])
Called when the runtime exits a builtin.