OptionalRuntimeObserver

Struct OptionalRuntimeObserver 

pub struct OptionalRuntimeObserver<'o>(pub Option<&'o mut dyn RuntimeObserver>);
Runtime observer that is optimised for the case where no observer is being used.

The trait RuntimeObserver is implemented on the Optional. This removes the dynamic dispatch overhead when no observer is being used.

Tuple Fields

0: Option<&'o mut dyn RuntimeObserver>