pub struct CompilationOutput {
pub lambda: Rc<Lambda>,
pub warnings: Vec<EvalWarning>,
pub errors: Vec<Error>,
}Expand description
Represents the result of compiling a piece of Nix code. If compilation was successful, the resulting bytecode can be passed to the VM.
Fields
lambda: Rc<Lambda>warnings: Vec<EvalWarning>errors: Vec<Error>Auto Trait Implementations
impl Freeze for CompilationOutput
impl !RefUnwindSafe for CompilationOutput
impl !Send for CompilationOutput
impl !Sync for CompilationOutput
impl Unpin for CompilationOutput
impl UnsafeUnpin for CompilationOutput
impl !UnwindSafe for CompilationOutput