struct BytecodeFrame {
lambda: Rc<Lambda>,
upvalues: Rc<Upvalues>,
ip: CodeIdx,
stack_offset: usize,
}Fields
lambda: Rc<Lambda>The lambda currently being executed.
upvalues: Rc<Upvalues>Optional captured upvalues of this frame (if a thunk or closure if being evaluated).
ip: CodeIdxInstruction pointer to the instruction currently being executed.
stack_offset: usizeStack offset, i.e. the frames “view” into the VM’s full stack.
Implementations
Sourceimpl BytecodeFrame
impl BytecodeFrame
Sourcefn upvalue(&self, idx: UpvalueIdx) -> &Value
fn upvalue(&self, idx: UpvalueIdx) -> &Value
Retrieve an upvalue from this frame at the given index.
Sourcefn inc_ip(&mut self) -> Op
fn inc_ip(&mut self) -> Op
Increment this frame’s instruction pointer and return the operation that the pointer moved past.
Sourcefn read_uvarint(&mut self) -> u64
fn read_uvarint(&mut self) -> u64
Read a varint-encoded operand and return it. The frame pointer is incremented internally.
Sourcepub fn error<T, IO>(&self, vm: &VM<'_, IO>, kind: ErrorKind) -> Result<T, Error>
pub fn error<T, IO>(&self, vm: &VM<'_, IO>, kind: ErrorKind) -> Result<T, Error>
Construct an error result from the given ErrorKind and the source span of the current instruction.
Sourcepub fn current_span(&self) -> Span
pub fn current_span(&self) -> Span
Returns the current span. This is potentially expensive and should only be used when actually constructing an error or warning.