pub struct OptionalCompilerObserver<'o>(pub Option<&'o mut dyn CompilerObserver>);Expand description
Compiler observer that is optimised for the case where no observer is being used.
The trait RuntimeObserver is implemented on the Optional
Tuple Fields
0: Option<&'o mut dyn CompilerObserver>Trait Implementations
Sourceimpl<'o> CompilerObserver for OptionalCompilerObserver<'o>
impl<'o> CompilerObserver for OptionalCompilerObserver<'o>
Sourcefn observe_compiled_toplevel(&mut self, lambda: &Rc<Lambda>)
fn observe_compiled_toplevel(&mut self, lambda: &Rc<Lambda>)
Called when the compiler finishes compilation of the top-level
of an expression (usually the root Nix expression of a file).
Sourcefn observe_compiled_lambda(&mut self, lambda: &Rc<Lambda>)
fn observe_compiled_lambda(&mut self, lambda: &Rc<Lambda>)
Called when the compiler finishes compilation of a
user-defined function. Read more
Sourcefn observe_compiled_thunk(&mut self, lambda: &Rc<Lambda>)
fn observe_compiled_thunk(&mut self, lambda: &Rc<Lambda>)
Called when the compiler finishes compilation of a thunk.
Sourceimpl<'o> Default for OptionalCompilerObserver<'o>
impl<'o> Default for OptionalCompilerObserver<'o>
Sourcefn default() -> OptionalCompilerObserver<'o>
fn default() -> OptionalCompilerObserver<'o>
Returns the “default value” for a type. Read more
Sourceimpl<'o> From<&'o mut dyn CompilerObserver> for OptionalCompilerObserver<'o>
impl<'o> From<&'o mut dyn CompilerObserver> for OptionalCompilerObserver<'o>
Sourcefn from(val: &'o mut dyn CompilerObserver) -> Self
fn from(val: &'o mut dyn CompilerObserver) -> Self
Converts to this type from the input type.
Sourceimpl<'o> From<Option<&'o mut dyn CompilerObserver>> for OptionalCompilerObserver<'o>
impl<'o> From<Option<&'o mut dyn CompilerObserver>> for OptionalCompilerObserver<'o>
Sourcefn from(val: Option<&'o mut dyn CompilerObserver>) -> Self
fn from(val: Option<&'o mut dyn CompilerObserver>) -> Self
Converts to this type from the input type.