pub struct OptionalRuntimeObserver<'o>(pub Option<&'o mut dyn RuntimeObserver>);Expand description
Runtime observer that is optimised for the case where no observer is being used.
The trait RuntimeObserver is implemented on the Optional
Tuple Fields
0: Option<&'o mut dyn RuntimeObserver>Trait Implementations
Sourceimpl<'o> From<&'o mut dyn RuntimeObserver> for OptionalRuntimeObserver<'o>
impl<'o> From<&'o mut dyn RuntimeObserver> for OptionalRuntimeObserver<'o>
Sourcefn from(val: &'o mut dyn RuntimeObserver) -> Self
fn from(val: &'o mut dyn RuntimeObserver) -> Self
Converts to this type from the input type.
Sourceimpl<'o> RuntimeObserver for OptionalRuntimeObserver<'o>
impl<'o> RuntimeObserver for OptionalRuntimeObserver<'o>
Sourcefn observe_enter_call_frame(
&mut self,
arg_count: usize,
lambda: &Rc<Lambda>,
call_depth: usize,
)
fn observe_enter_call_frame( &mut self, arg_count: usize, lambda: &Rc<Lambda>, call_depth: usize, )
Called when the runtime enters a new call frame.
Sourcefn observe_exit_call_frame(&mut self, frame_at: usize, stack: &[Value])
fn observe_exit_call_frame(&mut self, frame_at: usize, stack: &[Value])
Called when the runtime exits a call frame.
Sourcefn observe_suspend_call_frame(&mut self, frame_at: usize, stack: &[Value])
fn observe_suspend_call_frame(&mut self, frame_at: usize, stack: &[Value])
Called when the runtime suspends a call frame.
Sourcefn observe_enter_generator(
&mut self,
frame_at: usize,
name: &str,
stack: &[Value],
)
fn observe_enter_generator( &mut self, frame_at: usize, name: &str, stack: &[Value], )
Called when the runtime enters a generator frame.
Sourcefn observe_exit_generator(
&mut self,
frame_at: usize,
name: &str,
stack: &[Value],
)
fn observe_exit_generator( &mut self, frame_at: usize, name: &str, stack: &[Value], )
Called when the runtime exits a generator frame.
Sourcefn observe_suspend_generator(
&mut self,
frame_at: usize,
name: &str,
stack: &[Value],
)
fn observe_suspend_generator( &mut self, frame_at: usize, name: &str, stack: &[Value], )
Called when the runtime suspends a generator frame.
Sourcefn observe_generator_request(&mut self, name: &str, msg: &VMRequest)
fn observe_generator_request(&mut self, name: &str, msg: &VMRequest)
Called when a generator requests an action from the VM.
Sourcefn observe_tail_call(&mut self, frame_at: usize, lambda: &Rc<Lambda>)
fn observe_tail_call(&mut self, frame_at: usize, lambda: &Rc<Lambda>)
Called when the runtime replaces the current call frame for a
tail call.
Sourcefn observe_enter_builtin(&mut self, name: &'static str)
fn observe_enter_builtin(&mut self, name: &'static str)
Called when the runtime enters a builtin.
Sourcefn observe_exit_builtin(&mut self, name: &'static str, stack: &[Value])
fn observe_exit_builtin(&mut self, name: &'static str, stack: &[Value])
Called when the runtime exits a builtin.